// SPDX-License-Identifier: GPL-3.0-or-later

//! # gstore
//!
//! Global and local state management for GTK apps written in Rust.
//!
#[macro_use]
extern crate log;

mod store;
pub(crate) mod utils;

pub use store::*;

// Reexports
pub use once_cell;
pub use serde_json;

pub const INIT: &str = "init";
